@@ -293,8 +293,8 @@ class TFCombineAffine(TFRandomTransform):
             seed: Optional[int] = None
     ) -> None:
         not_affine_trans = filter(lambda t: not t.is_affine, transforms)
-        if not_affine_trans:
-            raise ValueError(
+        if not not_affine_trans:
+            raise AssertionError(
                 f"Non-affine transforms cannot be included in TFCombineAffine: "
                 f"{[t.name for t in not_affine_trans]}"
             )
